%Vector_Corr_CntlG.m   

% Copyright C 2004  Thomas A. Jones.  All rights reserved.
% Everyone is granted permission to copy, modify, and redistribute
% this program, but under the condition that this copyright notice
% remain intact and the Computers & Geosciences source be referenced. 
% This software has been tested extensively, but is distributed 
% WITHOUT ANY WARRANTY.  The author does not accept responsibility
% for any possible consequences of using it.

% Driver for GUI that obtains the controls that specify/define
% the dataset to be used (either external file or existing data array),
% and which variables in dataset for linear-circular and 
% circular-circular correlation analysis. 
% Also gets controls for calculations.

% Variables to be obtained and defaults:
%   NSkipHdr=0: Number of headers on data file to be skipped
%   NCols=0: Number of columns in data file
%   DegRad:  Input azimuths in degrees(0) or radians(1)?
%   NTrials: number of resampling trials (100 - 10000) default=1000 
%   X1,X2,X3,...,X12; Column in data file/set containing vars.
%   XName1, ..., XName12: Alpha identifiers of vars.
%   Az1, ..., Az12: Indicates which variables are azimuths (=1)
%   alfa: significance level for tests 
%     should be 0.10, 0.05, or 0.01 for CAssociation test
%     should be 0.10, 0.05, 0.025, 0.01, 0.005 for CircularRank test
%   Plots = 0: Are crossplots to be made? (yes=1)
%   WrOut = 1: Write results to external file (1=No, 0=Yes)
%   Data_Array='': Name of array that contains data 
%   RtrnCode = 0: Error return

% Set up the figure

Hfig_GUI = figure;       % Handle to figure window

set(Hfig_GUI, 'NumberTitle', 'off', ...
    'Name','Specify dataset/job controls', ...
    'Menubar','none', ...
    'Units','inches',  ...
    'Position', [0.3, 0.4, 5, 7.2]);

% Set up the entries

if datatype == 1

HL_FR1 = uicontrol(Hfig_GUI, 'Style','frame', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[6, 45, 76, 8]);
    
HL_1 = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 50, 50, 2], ...
    'String','Number of header records to skip');
HT_1 = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[70, 50, 8, 2], ...
    'String',num2str(NSkipHdr), ...
    'Callback','NSkipHdr = str2num(get(HT_1,''String''));');

HL_NC = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 48, 50, 2], ...
    'String','Number of columns in file');
HT_NC = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[70, 48, 8, 2], ...
    'String',num2str(NCols), ...
    'Callback','NCols = str2num(get(HT_NC,''String''));');

else
    
HL_DAr = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 49, 60, 2], ...
    'String','Specify name of data array to be used');
HT_DAr = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[65, 49, 15, 2], ...
    'String', Data_Array, ...
    'Callback','Data_Array = get(HT_DAr,''String'');');
    
end

HL_DR1 = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 45.5, 45, 2], ...
    'String','Input data in Degrees or Radians?');
HT_DR2 = uicontrol(Hfig_GUI, 'Style','push', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[54, 45.5, 10, 2], ...
    'String', 'DEGR.', ...
    'Callback','DegRad = str2num(''0'');');
HT_DR3 = uicontrol(Hfig_GUI, 'Style','push', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[69, 45.5, 10, 2], ...
    'String', 'Rad.', ...
    'Callback','DegRad = str2num(''1'');');

HL_FR2 = uicontrol(Hfig_GUI, 'Style','frame', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[6, 16, 76, 28]);
    
HL_X0 = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 41, 70, 2], ...
    'String','Variables     Column          Identifier                   Azimuth?');

HL_X1A = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[15, 39, 5, 2], ...
    'String',' X1');
HT_X1B = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[25, 39, 8, 2], ...
    'String',num2str(X1), ...
    'Callback','X1 = str2num(get(HT_X1B,''String''));');
HT_X1C = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[40, 39, 18, 2], ...
    'String',XName1, ...
    'Callback','XName1 = get(HT_X1C,''String'');');
HC_X1D = uicontrol(Hfig_GUI, 'Style','checkbox', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[65, 39, 5, 2], ...
    'Value', Az1, ...
    'Callback',['if get(HC_X1D,''Value'') == 1,' ...
                  'Az1 = str2num(''1'');,' ...
                'else,' ...
                  'Az1 = str2num(''0'');,'...
                'end']);

HL_X2A = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[15, 37, 5, 2], ...
    'String',' X2');
HT_X2B = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[25, 37, 8, 2], ...
    'String',num2str(X2), ...
    'Callback','X2 = str2num(get(HT_X2B,''String''));');
HT_X2C = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[40, 37, 18, 2], ...
    'String',XName2, ...
    'Callback','XName2 = get(HT_X2C,''String'');');
HC_X2D = uicontrol(Hfig_GUI, 'Style','checkbox', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[65, 37, 5, 2], ...
    'Value', Az2, ...
    'Callback',['if get(HC_X2D,''Value'') == 1,' ...
                  'Az2 = str2num(''1'');,' ...
                'else,' ...
                  'Az2 = str2num(''0'');,'...
                'end']);

HL_X3A = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[15, 35, 5, 2], ...
    'String',' X3');
HT_X3B = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[25, 35, 8, 2], ...
    'String',num2str(X3), ...
    'Callback','X3 = str2num(get(HT_X3B,''String''));');
HT_X3C = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[40, 35, 18, 2], ...
    'String',XName3, ...
    'Callback','XName3 = get(HT_X3C,''String'');');
HC_X3D = uicontrol(Hfig_GUI, 'Style','checkbox', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[65, 35, 5, 2], ...
    'Value', Az3, ...
    'Callback',['if get(HC_X3D,''Value'') == 1,' ...
                  'Az3 = str2num(''1'');,' ...
                'else,' ...
                  'Az3 = str2num(''0'');,'...
                'end']);

HL_X4A = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[15, 33, 5, 2], ...
    'String',' X4');
HT_X4B = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[25, 33, 8, 2], ...
    'String',num2str(X4), ...
    'Callback','X4 = str2num(get(HT_X4B,''String''));');
HT_X4C = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[40, 33, 18, 2], ...
    'String',XName4, ...
    'Callback','XName4 = get(HT_X4C,''String'');');
HC_X4D = uicontrol(Hfig_GUI, 'Style','checkbox', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[65, 33, 5, 2], ...
    'Value', Az4, ...
    'Callback',['if get(HC_X4D,''Value'') == 1,' ...
                  'Az4 = str2num(''1'');,' ...
                'else,' ...
                  'Az4 = str2num(''0'');,'...
                'end']);

HL_X5A = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[15, 31, 5, 2], ...
    'String',' X5');
HT_X5B = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[25, 31, 8, 2], ...
    'String',num2str(X5), ...
    'Callback','X5 = str2num(get(HT_X5B,''String''));');
HT_X5C = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[40, 31, 18, 2], ...
    'String',XName5, ...
    'Callback','XName5 = get(HT_X5C,''String'');');
HC_X5D = uicontrol(Hfig_GUI, 'Style','checkbox', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[65, 31, 5, 2], ...
    'Value', Az5, ...
    'Callback',['if get(HC_X5D,''Value'') == 1,' ...
                  'Az5 = str2num(''1'');,' ...
                'else,' ...
                  'Az5 = str2num(''0'');,'...
                'end']);

HL_X6A = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[15, 29, 5, 2], ...
    'String',' X6');
HT_X6B = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[25, 29, 8, 2], ...
    'String',num2str(X6), ...
    'Callback','X6 = str2num(get(HT_X6B,''String''));');
HT_X6C = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[40, 29, 18, 2], ...
    'String',XName6, ...
    'Callback','XName6 = get(HT_X6C,''String'');');
HC_X6D = uicontrol(Hfig_GUI, 'Style','checkbox', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[65, 29, 5, 2], ...
    'Value', Az6, ...
    'Callback',['if get(HC_X6D,''Value'') == 1,' ...
                  'Az6 = str2num(''1'');,' ...
                'else,' ...
                  'Az6 = str2num(''0'');,'...
                'end']);

HL_X7A = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[15, 27, 5, 2], ...
    'String',' X7');
HT_X7B = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[25, 27, 8, 2], ...
    'String',num2str(X7), ...
    'Callback','X7 = str2num(get(HT_X7B,''String''));');
HT_X7C = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[40, 27, 18, 2], ...
    'String',XName7, ...
    'Callback','XName7 = get(HT_X7C,''String'');');
HC_X7D = uicontrol(Hfig_GUI, 'Style','checkbox', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[65, 27, 5, 2], ...
    'Value', Az7, ...
    'Callback',['if get(HC_X7D,''Value'') == 1,' ...
                  'Az7 = str2num(''1'');,' ...
                'else,' ...
                  'Az7 = str2num(''0'');,'...
                'end']);

HL_X8A = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[15, 25, 5, 2], ...
    'String',' X8');
HT_X8B = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[25, 25, 8, 2], ...
    'String',num2str(X8), ...
    'Callback','X8 = str2num(get(HT_X8B,''String''));');
HT_X8C = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[40, 25, 18, 2], ...
    'String',XName8, ...
    'Callback','XName8 = get(HT_X8C,''String'');');
HC_X8D = uicontrol(Hfig_GUI, 'Style','checkbox', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[65, 25, 5, 2], ...
    'Value', Az8, ...
    'Callback',['if get(HC_X8D,''Value'') == 1,' ...
                  'Az8 = str2num(''1'');,' ...
                'else,' ...
                  'Az8 = str2num(''0'');,'...
                'end']);

HL_X9A = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[15, 23, 5, 2], ...
    'String',' X9');
HT_X9B = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[25, 23, 8, 2], ...
    'String',num2str(X9), ...
    'Callback','X9 = str2num(get(HT_X9B,''String''));');
HT_X9C = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[40, 23, 18, 2], ...
    'String',XName9, ...
    'Callback','XName9 = get(HT_X9C,''String'');');
HC_X9D = uicontrol(Hfig_GUI, 'Style','checkbox', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[65, 23, 5, 2], ...
    'Value', Az9, ...
    'Callback',['if get(HC_X9D,''Value'') == 1,' ...
                  'Az9 = str2num(''1'');,' ...
                'else,' ...
                  'Az9 = str2num(''0'');,'...
                'end']);

HL_X10A = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[15, 21, 5, 2], ...
    'String',' X10');
HT_X10B = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[25, 21, 8, 2], ...
    'String',num2str(X10), ...
    'Callback','X10 = str2num(get(HT_X10B,''String''));');
HT_X10C = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[40, 21, 18, 2], ...
    'String',XName10, ...
    'Callback','XName10 = get(HT_X10C,''String'');');
HC_X10D = uicontrol(Hfig_GUI, 'Style','checkbox', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[65, 21, 5, 2], ...
    'Value', Az10, ...
    'Callback',['if get(HC_X10D,''Value'') == 1,' ...
                  'Az10 = str2num(''1'');,' ...
                'else,' ...
                  'Az10 = str2num(''0'');,'...
                'end']);

HL_X11A = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[15, 19, 5, 2], ...
    'String',' X11');
HT_X11B = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[25, 19, 8, 2], ...
    'String',num2str(X11), ...
    'Callback','X11 = str2num(get(HT_X11B,''String''));');
HT_X11C = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[40, 19, 18, 2], ...
    'String',XName11, ...
    'Callback','XName11 = get(HT_X11C,''String'');');
HC_X11D = uicontrol(Hfig_GUI, 'Style','checkbox', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[65, 19, 5, 2], ...
    'Value', Az11, ...
    'Callback',['if get(HC_X11D,''Value'') == 1,' ...
                  'Az11 = str2num(''1'');,' ...
                'else,' ...
                  'Az11 = str2num(''0'');,'...
                'end']);

HL_X12A = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[15, 17, 5, 2], ...
    'String',' X12');
HT_X12B = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[25, 17, 8, 2], ...
    'String',num2str(X12), ...
    'Callback','X12 = str2num(get(HT_X12B,''String''));');
HT_X12C = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[40, 17, 18, 2], ...
    'String',XName12, ...
    'Callback','XName12 = get(HT_X12C,''String'');');
HC_X12D = uicontrol(Hfig_GUI, 'Style','checkbox', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[65, 17, 5, 2], ...
    'Value', Az12, ...
    'Callback',['if get(HC_X12D,''Value'') == 1,' ...
                  'Az12 = str2num(''1'');,' ...
                'else,' ...
                  'Az12 = str2num(''0'');,'...
                'end']);
   
HC_ALF1 = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 13, 65, 2], ...
    'String','Significance level (alfa) for inference');
HC_ALF2 = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[72, 13, 16, 2], ...
    'String', num2str(alfa), ...
    'Callback','alfa = str2num(get(HC_ALF2,''String''));');        

HC_TRL1 = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 11, 65, 2], ...
    'String','Number resampling trials if N small');
HC_TRL2 = uicontrol(Hfig_GUI, 'Style','edit', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[72, 11, 16, 2], ...
    'String', num2str(NTrials), ...
    'Callback','NTrials = str2num(get(HC_TRL2,''String''));');     
        
HC_2P1 = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 8, 45, 2], ...
    'String','Generate crossplots of variables?');
HC_2P2 = uicontrol(Hfig_GUI, 'Style','push', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[57, 8, 10, 2], ...
    'String', 'Yes', ...
    'Callback','Plots = str2num(''1'');');
HC_2P3 = uicontrol(Hfig_GUI, 'Style','push', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[72, 8, 10, 2], ...
    'String', 'NO', ...
    'Callback','Plots = str2num(''0'');');
               
HL_OFIL1 = uicontrol(Hfig_GUI, 'Style','text', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 5, 45, 2], ...
    'String','Write summary of job to output file?');
HT_OFIL2 = uicontrol(Hfig_GUI, 'Style','push', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[57, 5, 10, 2], ...
    'String', 'Yes', ...
    'Callback','WrOut = str2num(''0'');');
HT_OFIL3 = uicontrol(Hfig_GUI, 'Style','push', ...
    'Units','characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[72, 5, 10, 2], ...
    'String', 'NO', ...
    'Callback','WrOut = str2num(''1'');');

HPushCls = uicontrol(Hfig_GUI, 'Style','push', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[10, 1, 10, 2], ...
    'String','OK', ...
    'Callback','RtrnCode = str2num(''0'');close;');
HPushCncl = uicontrol(Hfig_GUI, 'Style','push', ...
    'Units', 'characters', 'Horizontalalignment','left', ...
    'FontSize',str2num('10'),  'FontUnits','points', ...
    'Position',[72, 1, 10, 2], ...
    'String','Cancel', ...
    'Callback','RtrnCode = str2num(''8'');close;');

uiwait





